Processor.App.processor\_utils.DomainRecord.\_\_init\_\_
========================================================

.. currentmodule:: Processor.App.processor_utils

.. automethod:: DomainRecord.__init__